binom.test <- function(x, n = NULL, p = 0.5, alternative = "two.sided", conf.level = 0.95, interactive = FALSE)
{   
  if (interactive == FALSE && !missing(x))
  {
    alpha = 1 - conf.level
  
    out = list()
  
    result = try(stats::binom.test(x, n, p, alternative, conf.level), silent = TRUE) #performs the test in third party function
    
    if (!is.null(attr(result, "class")))
    {
      if ((attr(result, "class") == "try-error") == TRUE)
      {
        return(result)
      }
    }
  
    if (length(x) == 1){
      out$test.statistic <- ((x/n)-p)/sqrt(p*(1-p)/n)
    } else
    {
      n = x[1]+x[2] #we can ignore n since all the info is in x on the user side, but we still need it for the calculation
      x = x[1]
      out$test.statistic <- ((x/n)-p)/sqrt(p*(1-p)/n)
    }
    out$p.value <- result$p.value
  
    out$alternative <- alternative
  
    if (out$p.value < alpha)
    {
      out$decision <- "Reject Null (accept alternative)"
    } else
    {
      out$decision <- "Null Hypothesis Possible (reject alternative)"
    }
  
    out$conf.int <- c(result$conf.int[1], result$conf.int[2])
  
  
    return(out) #out: out$test.statistic, p.value, alternative, decision, conf.int
  } else
  {
    out = execute.cli("binom.test")
    return(out)
  }
}