csv.prompt <- function(prompt = NULL)
{
  if (missing(prompt))
  {
    prompt == "Loading a CSV file: "
  }
  
  loop = TRUE
  
  while (loop)
  {
    good = TRUE
    
    writeLines(paste("For this: ", prompt, sep = ""))
    writeLines("Choose the file.")
    writeLines("CAUTION: Non-csv files may not be caught, loaded, and cause an error. Make sure the file is a CSV.")
    file = try(file.choose(), silent = TRUE)
    cat("\014")
    
    if (!is.null(attr(file, "class")))
    {
      if ((attr(file, "class") == "try-error") == TRUE)
      {
        good = FALSE
        writeLines("Warning: File does not exist, user cancelled, or some other problem occured.")
        loop = logical.prompt("Do you want to try again? ")
        if (loop == FALSE)
        {
          out <- FALSE
        }
      } else
      {
        good = TRUE
      }
    }
    
    if (good == TRUE) ## file load successful, proceeding...
    {
      loop = FALSE
      inner_loop = TRUE
      while(inner_loop)
      {
        writeLines("Do you have comma separated values (period for decimals) or semicolon separated values (comma for decimals)? ")
        comma_semi = readline("(Comma/Semicolon) ")
        while (comma_semi != "Comma" && comma_semi != "Semicolon")
        {
          writeLines("There is a typo.")
          comma_semi = readline("Comma seperated values or semicolon seperated values (Comma/Semicolon)? ")
        }
        
        writeLines("")
        header = logical.prompt("Is there a header in the CSV? ")
        fill = logical.prompt("Should fill be added where rows have unequal length (recommended for data frames)? ")
        if (comma_semi == "Comma")
        {
          out <- try(read.csv(file, header = header, fill = fill))
        } else if (comma_semi == "Semicolon")
        {
          out <- try(read.csv2(file, header = header, fill = fill))
        }
        
        if (!is.data.frame(out))
        {
          writeLines("Warning: There was a problem reading the CSV.")
          inner_loop = logical.prompt("Do you want to try again with the same file? ")
          if (inner_loop == FALSE)
          {
            loop = logical.prompt("Do you want to try again with a different file? ")
            if (loop == FALSE)
            {
              out <- FALSE
            }
          }
        } else #csv loading successful
        {
          inner_loop = FALSE
          loop = FALSE
        }
      }
    }
  }
  cat("\014")
  return(out)
}