dataframe.prompt <- function(prompt = NULL)
{
  if (missing(prompt))
  {
    prompt = "Building a data frame: "
  }
 
  writeLines("")
  writeLines(paste("For this dataframe: ", prompt, sep = ""))
  writeLines("")
  writeLines("You can create your own data frame, load one from a file, or use one in the global environment. ")
  
  how = readline("Do you want to create your own, load from a csv file, or use one in the global environment (C/L/G)? ")
  
  while (how != "C" && how != "L" && how != "G")
  {
    writeLines("There is a typo.")
    how = readline("Create your own data frame, load from a csv, or use one in the global environment (C/L/G)? ")
  }
  writeLines("")
  
  
  if (how == "G")
  {
    cat("\014")
    loop = TRUE
    
    while (loop)
    {
      out <- global.env(prompt)
      if (!is.data.frame(out))
      {
        loop = logical.prompt("A problem occured: I either do not have a value or it is not a dataframe. Do you want to try again? ")
        out = FALSE
      } else #global loading is good
      {
        loop = FALSE
      }
    }
  } else if (how == "C")
  {
    loop = TRUE
    
    while(loop) #we need this loop to handle typos and such
    {
      num_col = integer.prompt("Enter number of data columns: ")
      num_fac = integer.prompt("Enter number of factors: ")
      
      names = c()
      fac_names = c()
      
      if (num_col > 0) #perform these checks so we won't ask if num_col, num_fac = 0
      {
        for (i in seq(num_col))
        {
          names[i] = readline(paste("Enter name for column number ", i, ": ", sep = ""))
          cat("\n")
        }
        cat("\n")
      
        names = noquote(names)
      }
      
      if (num_fac > 0)
      {
        for (i in seq(num_fac))
        {
          fac_names[i] = readline(paste("Enter name for factor number ", i, ": ", sep = ""))
          cat("\n")
        }
        cat("\n")
        
        fac_names = noquote(fac_names)
      }
      sizes = integer.prompt("Enter the amount of data you have in each column (number of elements per column): ")
      
      col_args_list = c() #now that we have all the names, we need to string them together into a list
      fac_args_list = c()
      
      if (num_col > 0)
      {
        for (i in seq(num_col))
        {
          col_args_list[i] = paste(names[i], "=rep(0,", sizes, ")", sep = "")
        }
      
        col_args_list = noquote(col_args_list)
      }
      
      if (num_fac > 0)
      {
        for (i in seq(num_fac))
        {
          fac_args_list[i] = paste(fac_names[i], "=factor(rep(0,", sizes, "))", sep = "")
        }
      
        fac_args_list = noquote(fac_args_list)
      }
      
      col_args = NULL #now that we have a list, we need to turn this list into a string of arguments (with commas and everything)
      fac_args = NULL
      
      if (num_col > 0)
      {
        for (i in seq(num_col))
        {
          if (i == 1) ## the first argument doesn't have anything in front fo it, so we cannot append like we do in "else"
          {
            col_args = col_args_list[i]
          } else
          {
            col_args = paste(col_args, ", ", col_args_list[i], sep = "")
          }
        }
      }
      
      if (num_fac > 0)
      {
        for (i in seq(num_fac))
        {
          if (i == 1)
          {
            fac_args = fac_args_list[i]
          } else
          {
            fac_args = paste(fac_args, ", ", fac_args_list[i], sep = "")
          }
        }
      }
      out <- TRUE
      
      all_args = "data.frame("  ## the very very beginning of our string which will be parsed and evaluated
      if (num_col > 0 && num_fac > 0) ## depending on the case, we may or may not have columns or factors to add to this string
      {
        all_args = paste(all_args, col_args, ", " , fac_args, ")", sep = "")
      } else if (num_col > 0)
      {
        all_args = paste(all_args, col_args, ")", sep = "")
      } else if (num_fac > 0)
      {
        all_args = paste(all_args, fac_args, ")", sep = "")
      } else
      {
        out <- FALSE ## if nothing to add, make this false so we can report a cancelleation
      }
      
      if (out == FALSE)
      {
        loop = logical.prompt("You cancelled the creation of the data frame. Do you want to try again?")
        if (loop == FALSE)
        {
          break #breaks out of the loop entirely
        }
      }
      
      parsed = parse(text = all_args) #prep the string for evaluation
      
      writeLines("")
      writeLines("Going to try to create the data frame now...")
      writeLines("")
      
      out <- try(eval(parsed), silent = TRUE) ## evaluate
      
      if (!is.data.frame(out))
      {
        loop = logical.prompt("A problem occured. Do you want to try again? ")
        out = FALSE
      } else ## creation successful
      {
        loop = FALSE
      }
    }
  } else if (how == "L")
  {
    cat("\014")
    loop = TRUE
    while(loop)
    {
      out <- csv.prompt(prompt)
      if (!is.data.frame(out))
      {
        loop = logical.prompt("A problem occured. Do you wnat to try again? ")
        if (loop == FALSE)
        {
          out <- FALSE
          break
        }
      } else
      {
        loop = FALSE
      }
    }
  }
  if (is.data.frame(out)) ## if we failed to get a data frame out will be false, so skip this
  {
    if (.Platform$OS.type == "unix")
    {
      ## I don't know a better way to make sure editing works on a non-Windows systems (some users report problems if
      ## a third party app or component is not installed or running), so I'm just going to give all non-Windows users this
      ## caution until we have a better solution
      
      writeLines("CAUTION: GUI required for dataframe editing. Mac users should have Xquartz.")
    }
    edit_loop = logical.prompt("Do you want to edit this data frame? ")
  
    while(edit_loop)
    {
      out = edit(out)
      print(out)
      writeLines("")
      edit_loop = logical.prompt("Do you want to continue editing this data frame? ")
    }
  }
  cat("\014")
  return(out)
}