execute.cli <- function(name = NULL)
{
  enableJIT(3)
  
  if (is.null(name)) ## if there is no name, go to interactive.cli, where we will find out the name
  {
    out <- interactive.cli()
    return(out)
  }
  
  main <- function(name)
  {
     #clears console
    writeLines("Press escape key at any time to exit.")
    writeLines("")
    writeLines("Pleae be aware that all input is case sensitive.")
    writeLines("")
    
    if (name == "binom.test")  ############### binom.test ###########################################################
    {
      print(help(binom.test, package = HypoTest, verbose = F))
      
      x = 1
      n = 0
      while (n <= x)
      {
        x = integer.prompt("Enter the number of successes: ")
        n = integer.prompt("Enter the number of trials (must be greater or equal to the number of successes): ")
      }
      p = numeric.prompt("What is the hypothesized probability of success (this is the null hypothesis): ")
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out = HypoTest::binom.test(x = x, n = n, p = p, alternative = alternative, conf.level = conf.level)
      return(out)
      
    } else if (name == "chisq.test") ############## chisq.test ##########################################################
    {
      print(help(chisq.test, package = HypoTest, verbose = F))
      
      data_type = readline("Do you have a vector of data, a matrix of data, or a factor (V/M/F): ")
      while(!(data_type == "V" || data_type == "M" || data_type == "F"))
      {
        writeLines("There is a typo. Try again.")
        data_type = readline("Do you have a vector of data, a matrix of data, or a factor (V/M/F): ")
      }
      if (data_type == "V")
      {
        x = vector.prompt("Enter the first data set: ")
        y = NULL
        second = logical.prompt("Do you have a second data set to enter (this is NOT for the probabilities): ")
        while (second)
        {
          y = vector.prompt("Enter the second data set: ")
          if (length(x) != length(y))
          {
            writeLines("Warning: Lengths of data are not equal, re-enter second data set.")
          }
          else
          {
            second = FALSE
          }
        }
        
      } else if (data_type == "M")
      {
        x = matrix.prompt("Enter data set: ")
        y = NULL
      } else if (data_type == "F")
      {
        x = factor.prompt("Enter the first factor: ")
        y = factor.prompt("Enter the second factor: ")
        
        while (length(x) != length(y))
        {
          writeLines("Warning: Lengths are not equal, re-enter second data set.")
          y = factor.prompt("Enter the second factor: ")
        }
      }
      
      correct = logical.prompt("Should continuity correction be applied? ")
      prob = logical.prompt("Do you want to enter a list of probabilities? ")
      if (!prob)
      {
        p = NULL #so I don't have to write another case if we don't supply p since that would take less time than writing this
      }
      
      loop = prob
      
      while(loop) #make sure we only get the list of probabilities if we want to use them
      {
        p = vector.prompt("Enter the list of probabilities: ")
        if (length(p) != length(x))
        {
          writeLines("Warning: Lengths of the probabilites and the data are not equal, re-enter probabilities.")
        } else
        {
          loop = FALSE
        }
      }
      if (prob)
      {
        rescale.p = logical.prompt("Should the probabilities be rescaled so they sum to 1? ")
      } else
      {
        rescale.p = NULL
      }
      
      simulate.p.value = logical.prompt("Should the Monte Carlo simulation be used to compute the p values? ")
      if (simulate.p.value == TRUE)
        B = integer.prompt("How many replicates should be used in the Monte Carlo test? ")
      else
        B = 2000
      
      out <- HypoTest::chisq.test(x,y,correct,p, rescale.p,simulate.p.value,B)
      return(out)
      
    } else if (name == "goodfit.predict") ################# goodfit.predict ####################################################
    {
      print(help(goodfit.predict, package = HypoTest, verbose = F))
      
      data_type = readline("Do you have a vector of data, a matrix of data, or a data frame (V/M/D): ")
      while(!(data_type == "V" || data_type == "M" || data_type == "D"))
      {
        writeLines("There is a typo. Try again.")
        data_type = readline("Do you have a vector of data, a matrix of data, or a data frame (V/M/D): ")
      }
      
      if (data_type == "D")
      {
        writeLines("Please enter the frequencies in the first column and counts in the second column.")
        x = dataframe.prompt("Enter the data frame (caution: no typo checking): ")
        if (!is.data.frame(x))
        {
          writeLines("Something happened and we cannot use a dataframe. We will use a vector instead.")
          x = vector.prompt("Enter a vector of counts: ")
        }
      } else if (data_type == "M")
      {
        writeLines("For this matrix, please enter the frequencies in the first column and the counts in the second column.")
        x = matrix.prompt("Enter the matrix (freq in the first column, counts in the second column): ", byrow = FALSE)
      } else if (data_type == "V")
      {
        x = vector.prompt("Enter a vector of counts: ")
      }
      
      loop = TRUE
      while(loop)
      {
        type = readline("Which distribution should be fit (poisson/binomial/nbinomial): ")
        if (!(type == "poisson" || type == "binomial" || type == "nbinomial"))
        {
          writeLines("There is a typo. Try again.")
          type = readline("Which distribution should be fit (poisson/binomials/nbinomial): ")
        } else
        {
          loop = FALSE
        }
      }
      
      loop = TRUE
      while(loop)
      {
        method = readline("How should the distribution be fit (ML/MinChisq): ")
        if (!(method == "ML" || method == "MinChisq"))
        {
          writeLines("There is a typo. Try again.")
          method = readline("Which distribution should be fit (ML/MinChisq): ")
        } else
        {
          loop = FALSE
        }
      }
      
      logic = logical.prompt("Do you wish to give the distribution parameters? ")
      if (logic)
      {
        size = integer.prompt("Enter the size: ")
        inner_logic = logical.prompt("Do you also wish to supply the prob parameter? ")
        if (inner_logic)
        {
          prob = numeric.prompt("Enter the probability: ")
          par = list(size = size, prob = prob)
        } else
        {
          par = list(size = size)
        }
      } else
      {
        par = NULL
      }
      
      loop = TRUE
      while(loop)
      {
        predict.type = readline("Do you want the fitted values of the prediction or the probability (response/prob): ")
        if (!(predict.type == "response" || predict.type == "prob"))
        {
          writeLines("There is a typo. Try again.")
          type = readline("Fitted values or the probability (response/prob): ")
        } else
        {
          loop = FALSE
        }
      }
      
      out <- HypoTest::goodfit.predict(x = x, type = type, method = method, par = par, predict.type = predict.type)
      return(out)
    } else if (name == "ks.test") ###################### ks.test #########################################################
    {
      print(help(ks.test, package = HypoTest, verbose = F))
      x = vector.prompt("Enter the first set of data: ")
      
      type = readline("Do you have a numeric vector of data or a character string for the y parameter (V/S)? ")
      while (!(type == "V" || type == "S"))
      {
        writeLines("There is a typo. Try again.")
        type = readline("Numeric vector or character string (V/S)? ")
      }
      
      if (type == "V")
      {
        y = vector.prompt("Enter the second set of data: ")
      } else
      {
        y = readline("Enter the name of a cumulative distribution function such as \"pnorm\" or \"pexp\", without quotes (caution: no typo checking): ")
      }
      logic = logical.prompt("Do you have any parameters you wish to pass to \"...\" ? ")
      if (logic)
      {
        # we can't use something like 1/mean(data) and pass it in without a bunch of string parsing like we do in dataframe
        # we can't do much typo checking either, hence the numeric requirement
        
        dots = numeric.prompt("Enter numeric parameters for \"...\": ")
      } else
      {
        dots = NULL
      }
      
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      exact = logical.prompt("Should the exact p-value be computed? ")
      
      if (is.null(dots))
      {
        out <- HypoTest::ks.test(x = x, y = y, alternative = alternative, conf.level = conf.level, exact = exact)
      } else
      {
        out <- HypoTest::ks.test(x = x, y = y, dots, alternative = alternative, conf.level = conf.level, exact = exact)
      }
      return(out)
    } else if (name == "mcnemar.test") ############################# mcnemar.test ##########################################
    {
      print(help(mcnemar.test, package = HypoTest, verbose = F))
      
      type = readline("Do you have a matrix or a factor (M/F)? ")
      while (!(type == "M" || type == "F"))
      {
        writeLines("There is a typo. Try again.")
        type = readline("Do you have a matrix or a factor (M/F)? ")
      }
      
      while (type == "M")
      {
        x = matrix.prompt("Enter at least a 2 dimensional contingency table in the form of a matrix: ", byrow = F, square = T)
        if (dim(x)[1] < 2)
        {
          writeLines("You need at least 2 dimensions.")
        } else
        {
          break
        }
      }
      
      if (type == "F")
      {
        x = factor.prompt("Enter the first factor: ")
        y = factor.prompt("Enter the second factor: ")
        
        while (length(x) != length(y))
        {
          writeLines("Warning: Lengths are not equal, re-enter second data set.")
          y = factor.prompt("Enter the second factor: ")
        }
      }
      
      correct = logical.prompt("Should continutiy correction be applied? ")
      conf.level = conf.level.prompt()
      
      out <- HypoTest::mcnemar.test(x = x, correct = correct, conf.level = conf.level)
      return(out)
    } else if (name == "prop.test") ############################# prop.test ################################################
    {
      print(help(prop.test, package = HypoTest, verbose = F))
      type = readline("Do you have a vector of counts or a matrix (V/M)? ")
      while (!(type == "V" || type == "M"))
      {
        writeLines("There is a typo. Try again.")
        type = readline("Do you have a vector or a matrix (V/M)? ")
      }
      if (type == "V")
      {
        x = vector.prompt("Enter a vector of successes: ")
      } else
      {
        while(TRUE)
        {
          x = matrix.prompt("Enter a 2 column matrix giving the counts of succsses and failures: ")
          if (dim(x)[2] != 2) #after all the user's effort to input a bad matrix, now is a great time to complain
          {
            writeLines("There must be 2 columns in the matrix.")
          } else
          {
            break
          }
        }
      }
      if (type != "M")
      {
        n = vector.prompt("Enter a vector containing the number of trials: ")
      } else
      {
        n = NULL
      }
      
      loop = logical.prompt("Do you have probabilities that you wish to provide?")
      
      while (loop)
      {
        writeLines("The vector of probabilites must be the same length as the number of groups in the data.")
        p = vector.prompt("Enter a vector of probabilities of success (between 0 and 1) (caution: no length checking): ")
        for (i in seq(length(p)))
        {
          if (p[i] > 1 || p[i] < 0)
          {
            loop = TRUE
            writeLines("There is a typo: p must be between 0 and 1")
            break
          } else
          {
            loop = FALSE
          }
        }
      }
      
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      correct = logical.prompt("Should continuity correction be applied? ")
      
      out <- HypoTest::prop.test(x = x, n = n, p = p, alternative = alternative, conf.level = conf.level, correct = correct)
      return(out)
    } else if (name == "sigma.test") ###################################### sigma.test #####################################
    {
      print(help(sigma.test, package = HypoTest, verbose = F))
      x = vector.prompt("Enter the data: ")
      sigma = numeric.prompt("Enter the sample standard deviation: ")
      sigmasq = numeric.prompt("Enter the hypothesized population variance (enter -1 to use the square of the std deviation): ")
      if (sigmasq == -1)
      {
        sigmasq == sigma ^ 2
      }
      
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::sigma.test(x = x, s = sigma, sigmasq = sigmasq, alternative = alternative, conf.level = conf.level)
      
      return(out)
    } else if (name == "sigmasum.test") ################################### sigmasum.test #############################
    {
      print(help(sigmasum.test, package = HypoTest, verbose = F))
      n = integer.prompt("How big is the sample: ")
      sigma = numeric.prompt("Enter the sample standard deviation: ")
      sigmasq = numeric.prompt("Enter the hypothesized population variance (enter -1 to use the square of the std deviation): ")
      if (sigmasq == -1)
      {
        sigmasq == sigma ^ 2
      }
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::sigmasum.test(n = n, s = sigma, sigmasq = sigmasq, alternative = alternative, conf.level = conf.level)
      
      return(out)
    } else if (name == "t.test")
    {
      print(help(t.test, package = HypoTest, verbose = F))
      x = vector.prompt("Enter the data: ")
      logic = logical.prompt("Do you have a second set of data? ")
      if (logic)
      {
        y = vector.prompt("Enter the second set of data: ")
      } else
      {
        y = NULL
      }
      
      mu = numeric.prompt("Enter the hypothesized mean (this is the null hypothesis): ")
      alternative = alternative.prompt()
      if (logic)
      {
        paired = logical.prompt("Do you have dependent data (also known as paired data)? ")
        var.equal = logical.prompt("Are the variances equal? ")
      } else
      {
        paired = FALSE
        var.equal = FALSE
      }
      conf.level = conf.level.prompt()
      
      out <- HypoTest::t.test(x = x, y = y, mu = mu, alternative = alternative, paired = paired, var.equal = var.equal, conf.level = conf.level)
      return(out) 
    } else if (name == "tsum.test") #################################### tsum.test #############################################
    {
      print(help(tsum.test, package = HypoTest, verbose = F))
      n.x = numeric.prompt("Enter the sample size: ")
      mean.x = numeric.prompt("Enter the sample mean: ")
      s.x = numeric.prompt("Enter the sample standard deviation: ")
      
      logic = logical.prompt("Do you have a second sample? ")
      if (logic)
      {
        n.y = numeric.prompt("Enter the second sample size: ")
        mean.y = numeric.prompt("Enter the second sample mean: ")
        s.y = numeric.prompt("Enter the second sample standard deviation: ")
      } else
      {
        n.y = NULL
        mean.y = NULL
        s.y = NULL
      }
      mu = numeric.prompt("Enter the hypothesized mean (this is the null hypothesis): ")
      alternative = alternative.prompt()
      if (logic)
      {
        var.equal = logical.prompt("Are the variances equal? ")
      } else
      {
        var.equal = FALSE
      }
      conf.level = conf.level.prompt()
      
      out <- HypoTest::tsum.test(n.x = n.x, mean.x = mean.x, s.x = s.x, n.y = n.y, mean.y = mean.y, s.y = s.y, mu = mu,
                                 alternative = alternative, var.equal = var.equal, conf.level = conf.level)
      
      return(out)
    } else if (name == "var.test") ########################## var.test ###############################################
    {
      print(help(var.test, package = HypoTest, verbose = F))
      x = vector.prompt("Enter the first data: ")
      y = vector.prompt("Enter the second data: ")
      ratio = numeric.prompt("Enter the ratio: ")
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::var.test(x = x, y = y, ratio = ratio, alternative = alternative, conf.level = conf.level)
      return(out)
    } else if (name == "varsum.test") ######################### varsum.test ###########################################
    {
      print(help(varsum.test, package = HypoTest, verbose = F))
      n.x = integer.prompt("Enter the first sample size: ")
      s.x = numeric.prompt("Enter the first sample standard deviation: ")
      n.y = integer.prompt("Enter the second sample size: ")
      s.y = numeric.prompt("Enter the second standard deviation: ")
      ratio = numeric.prompt("Enter the ratio (this is the null hypothesis): ")
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::varsum.test(n.x = n.x, s.x = s.x, n.y = n.y, s.y = s.y, ratio = ratio, alternative = alternative, conf.level = conf.level)
      
      return(out)
    } else if (name == "z.test") ################################ z.test ##########################################
    {
      print(help(z.test, package = HypoTest, verbose = F))
      x = vector.prompt("Enter the data: ")
      sigma.x = numeric.prompt("Enter the population standard deviation: ")
      logic = logical.prompt("Do you have a second set of data? ")
      if (logic)
      {
        y = vector.prompt("Enter the second set of data: ")
        sigma.y = numeric.prompt("Enter the second population standard deviation: ")
      } else
      {
        y = NULL
        sigma.y = NULL
      }
      
      mu = numeric.prompt("Enter the hypothesized mean (this is the null hypothesis): ")
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::z.test(x = x, sigma.x = sigma.x, y = y, sigma.y = sigma.y, mu = mu, alternative = alternative, conf.level = conf.level)
      return(out)
    } else if (name == "zsum.test") ########################## zsum.test ####################################################
    {
      print(help(zsum.test, package = HypoTest, verbose = F))
      n.x = integer.prompt("Enter the sample size: ")
      mean.x = numeric.prompt("Enter the sample mean: ")
      sigma.x = numeric.prompt("Enter the population standard deviation: ")
      logic = logical.prompt("Do you have a second sample? ")
      if (logic)
      {
        n.y = integer.prompt("Enter the second sample size: ")
        mean.y = numeric.prompt("Enter the second sample mean: ")
        sigma.y = numeric.prompt("Enter the second population standard deviation: ")
      } else
      {
        n.y = NULL
        mean.y = NULL
        sigma.y = NULL
      }
      
      mu = numeric.prompt("Enter the hypothesized mean (this is the null hypothesis): ")
      alternative = alternative.prompt()
      conf.level = conf.level.prompt()
      
      out <- HypoTest::zsum.test(n.x = n.x, mean.x = mean.x, sigma.x = sigma.x, n.y = n.y, mean.y = mean.y, sigma.y = sigma.y,
                                 mu = mu, alternative = alternative, conf.level = conf.level)
      return(out)
    } else if (name == "aov") ################################################### aov ##############################3
    {
      print(help(aov, package = HypoTest, verbose = F))
      writeLines("")
      writeLines("Enter a formula that has the following form: MyData~MyFactor1+MyFactor2.")
      writeLines("")
      writeLines("Use a tilde (~) to separate quantitative/ categorical data, and use a plus (+) to separate factors.")
      writeLines("You may use a larger or smaller model than the example above.")
      writeLines("")
      
      formula = readline("Enter the formula (Caution: Minimal typo checking): ")
      while (TRUE)
      {
        formula = try(as.formula(formula), silent = T) #because Yoda isn't always right
        if ((attr(formula, "class") == "formula") == TRUE)
        {
          break
        } else
        {
          formula = readline("Could not convert string to a formula. Try again: ")
        }
      }
      data = dataframe.prompt("Enter a dataframe that has the variables that you specified in the formula: ")
      
      out <- HypoTest::aov(formula=formula,data=data)
      return(out)
    } else if (name == "lm") ############################################## lm ##############################################
    {
      print(help(lm, package = HypoTest, verbose = F))
      writeLines("")
      writeLines("Enter a formula that has the following form: MyData~MyFactor1+MyFactor2.")
      writeLines("")
      writeLines("Use a tilde (~) to separate quantitative/ categorical data, and use a plus (+) to separate factors.")
      writeLines("You may use a larger or smaller model than the example above.")
      writeLines("")
      
      formula = readline("Enter the formula (Caution: Minimal typo checking): ")
      while (TRUE)
      {
        formula = try(as.formula(formula), silent = T)
        if ((attr(formula, "class") == "formula") == TRUE)
        {
          break
        } else
        {
          formula = readline("Could not convert string to a formula. Try again: ")
        }
      }
      data = dataframe.prompt("Enter a dataframe that has the variables that you specified in the formula: ")
      
      out <- HypoTest::lm(formula=formula,data=data)
      return(out)
    } else
    {
      out <- paste("This function, ", name, ", is not implemented in the interactive environment at this time. Manual use required.",
                   sep = "")
      return(out)
    }
  } # end main ################################################################ end main ##################################
  
  loop = TRUE
  while(loop)
  {
    good = TRUE
    
    out <- main(name)
    if (!is.null(attr(out, "class")))
    {
      if ((attr(out, "class") == "try-error") == TRUE)
      {
        good = FALSE
        
        
        # because why not say this
        writeLines("ERROR")
        writeLines("You know that feeling when you want a pizza, but you get a cook tossing a mouse being chased by a lion?")
        writeLines("")
        writeLines("Yep, something went wrong...very wrong...")
        writeLines("")
        writeLines("")
        try(Sys.sleep(4)) #may not work on all systems
        
        print(out)
        
        writeLines("")
        writeLines("")
        loop = logical.prompt("Do you want to face the lion and try again? ")
      } else
      {
        good = TRUE
      }
    }
    
    if (good == TRUE)
    {
      return(out)
    }
  }

}

function.execute.cli <- function(name = NULL) #legacy support
{
  return(execute.cli(name))
}