matrix.prompt <- function(prompt=NULL, byrow = TRUE, square = FALSE)
{
  if (missing(prompt))
  {
    prompt = "Building a matrix: "
  }
  
  writeLines("")
  writeLines("You can either create your own matrix or use one in the global environment. ")
  writeLines("")
  writeLines(paste("For this matrix: ", prompt, sep = ""))
  global = logical.prompt("Do you want to use a matrix in the global environment? ")
  cat("\014")
  writeLines("")
  while(global)
  {
    out <- global.env(prompt)
    for (i in seq(length(out))) #make sure what we loaded actually is a numeric matrix
    {
      if (is.logical(out)) #if we got false this will catch it
      {
        manual = TRUE
        break
      }
      if (is.na(out[i]) || !is.numeric(out[i])) #if there is not a number this will catch it
      {
        manual = TRUE
        break
      } else
      {
        manual = FALSE
      }
    }
    
    if (manual == FALSE)
    {
      return(out)
    } else
    {
      writeLines("There is a problem in the variable specified.")
      global = logical.prompt("Do you want to try again? ")
    }
  }
  
  while(TRUE) #manual matrix creation
  {
    num_row = integer.prompt("Enter the number of rows in your matrix: ")
    num_col = integer.prompt("Enter the number of columns in your matrix: ")
    
    if (num_col != num_row && square == TRUE)
    {
      writeLines("The number of rows and the number of columns must be the same.")
    } else
    {
      break
    }
  }
  
  writeLines("")
  writeLines("You will enter the data as a vector. Here's how it works.")
  writeLines(paste("Example Data Input for a ", num_row, " by ", num_col, " matrix.", sep = ""))
  
  num_data = num_col * num_row
  sample = seq(num_data) #creates a sample so the user knows how the matrix will be filled in from the supplied vector
  
  writeLines("Sample Data: ")
  print(sample)
  writeLines("")
  writeLines("Example Output: ")
  
  if (byrow == TRUE)
  {
    example_matrix = matrix(sample, num_row, num_col, byrow= TRUE)
  } else
  {
    example_matrix = matrix(sample, num_row, num_col, byrow= FALSE)
  }
  print(example_matrix)
  writeLines("")
  
  list = 1
  
  while((length(list) != num_data) || num_data == 1) #makes sure we get all the data in the matrix
  {
    writeLines("")
    
    if (byrow == TRUE)
    {
      number_data = paste("You need to enter ", num_data, " data values for a ", num_row, " by ", num_col, " matrix, by row: ", sep = "")
    } else
    {
      number_data = paste("You need to enter ", num_data, " data values for a ", num_row, " by ", num_col, " matrix, by column: ", sep = "")
    }
    
    list = vector.prompt(paste(prompt, number_data, sep = ""))
    
    writeLines("")
    if (num_data == 1 && length(list) == 1)
    {
      break
    }
  }
  
  out = matrix(list, num_row, num_col, byrow=byrow)
  writeLines("")
  return(out)
}