sigma.test <- function(x, s = 1, sigmasq = s^2, alternative = "two.sided", conf.level = 0.95, interactive = FALSE)
{
  sigma.test.function <- function(x, s = 1, sigmasq = s^2, alternative = "two.sided", conf.level = 0.95)
  {
    alpha = 1-conf.level
    
    sigma = s
  
    out = list()
  
    n = length(x)
    s = round(sd(x),3);
    df = n-1
    chisq0 = (n-1)*sigma^2/sigmasq
  
    out$test.statistic <- chisq0
  
    if (alternative == "less") chicritical = qchisq(alpha,df)
    else if (alternative == "greater") chicritical = qchisq(alpha, df, lower.tail = FALSE)
    else {
      z1 = qchisq(alpha/2,df)
      z2 = qchisq(alpha/2, df, lower.tail = FALSE)
      chicritical = c(z1,z2)
    }  
  
    if (alternative == "less") Pvalue = pchisq(chisq0, df)
    else if (alternative == "greater") Pvalue = pchisq(chisq0, df, lower.tail = FALSE)
    else {
      if (pchisq(chisq0,df) >= 0.5) Pvalue = 2*pchisq(chisq0, df,lower.tail = FALSE)
      else Pvalue = 2*pchisq(chisq0, df)
    }

    out$p.value <- Pvalue
    out$alternative <- alternative
  
    if (out$p.value < alpha)
    {
      out$decision <- "Reject Null (accept alternative)"
    } else
    {
      out$decision <- "Null Hypothesis Possible (reject alternative)"
    }
  
    chisqleft= qchisq(alpha/2,df)
    chisqright = qchisq(1-alpha/2,df)
    Lower = df*sigma^2/chisqright
    Upper = df*sigma^2/chisqleft
    CI = c(Lower,Upper)
  
    out$conf.int <- CI
    out$critical.value <- chicritical
  
    return(out) #out: out$test.statistic, p.value, alternative, decision, conf.int, critical.value
  }
  
  if (interactive == FALSE && !missing(x))
  {
    out <- try(sigma.test.function(x = x, s = s, sigmasq = sigmasq, alternative = alternative, conf.level = conf.level))
    if (!is.null(attr(out, "class")))
    {
      if ((attr(out, "class") == "try-error") == TRUE)
      {
        return(out)
      }
    }
    return(out)
  } else
  {
    out <- execute.cli("sigma.test")
    return(out)
  }
}
