t.test <- function(x, y = NULL, mu = 0, alternative = "two.sided", paired = FALSE, var.equal = FALSE, conf.level = 0.95,
                   interactive = FALSE)
{
  if (interactive == FALSE && !missing(x))
  {
    alpha = 1 - conf.level
  
    out = list()
  
    result = try(stats::t.test(x, y, alternative, mu, paired, var.equal, conf.level), silent = TRUE) #performs the test in third party function
    if (!is.null(attr(result, "class")))
    {
      if ((attr(result, "class") == "try-error") == TRUE)
      {
        return(result)
      }
    }
    
    if (is.null(y)){
      n = length(x)
      df = n-1
      if (alternative == "less") tcritical = qt(alpha,df)
      else if (alternative == "greater") tcritical = qt(alpha,df,lower.tail = FALSE)
      else {
        t1 = qt(alpha/2,df)
        t2 = qt(alpha/2,df,lower.tail = FALSE)
        tcritical = c(t1,t2)
      }
    }
    
    out$test.statistic <- as.numeric(result$statistic)
    out$p.value <- result$p.value
    out$alternative <- alternative
  
    if (out$p.value < alpha)
    {
      out$decision <- "Reject Null (accept alternative)"
    } else
    {
      out$decision <- "Null Hypothesis Possible (reject alternative)"
    }
  
    out$conf.int <- c(result$conf.int[1], result$conf.int[2])
  
    if (is.null(y)){
    out$critical.value <- tcritical
    }
  
    return(out) # out$test.statistic, p.value, alternative, decision, conf.int, critical.value
  } else
  {
    out <- execute.cli("t.test")
    return(out)
  }
}
