varsum.test <- function(n.x, s.x, n.y, s.y, ratio = 1, alternative = "two.sided", conf.level = 0.95, interactive = FALSE)
{ 
  varsum.test.function <- function(n.x, s.x, n.y, s.y, ratio = 1, alternative = "two.sided", conf.level = 0.95)
  {
    alpha = 1 - conf.level
  
    out = list()
  
    f = 1/ratio * s.x^2/s.y^2 #test statistic
  
    out$test.statistic <- f
  
    df1 = n.x-1
    df2 = n.y-1
  
    if (alternative == "greater")
    {
      p.value = pf(f,df1,df2,lower.tail=F)
    } else if (alternative == "less")
    {
      p.value = pf(f,df1,df2,lower.tail=T)
    } else
    {
      if (f < 1)
      {
        p.value = 2*pf(f,df1,df2)
      } else
      {
        p.value = 2*pf(f,df1,df2,lower.tail=F)
      }
    }
  
    out$p.value <- p.value
    out$alternative <- alternative
  
    if (out$p.value < alpha)
    {
      out$decision <- "Reject Null (accept alternative)"
    } else
    {
      out$decision <- "Null Hypothesis Possible (reject alternative)"
    }
  
    var_ratio = s.x^2/s.y^2
  
    if (out$alternative == "two.sided") {
      beta = alpha / 2
      out$conf.int <- c(var_ratio / qf(1 - beta, df1, df2),
              var_ratio / qf(beta, df1, df2))
    } else if (out$alternative == "greater") {
    out$conf.int <- c(var_ratio / qf(conf.level, df1, df2), Inf)
    } else
    {
    out$conf.int <- c(0, var_ratio / qf(1 - conf.level, df1, df2))}
    
    return(out) #out: out$test.statistic, p.value, alternative, decision, conf.int
  }
  
  if (interactive == FALSE && !missing(n.x) && !missing(s.x))
  {
    out <- try(varsum.test.function(n.x = n.x, s.x = s.x, n.y = n.y, s.y = s.y, ratio = ratio, alternative = alternative, conf.level = conf.level))
    if (!is.null(attr(out, "class")))
    {
      if ((attr(out, "class") == "try-error") == TRUE)
      {
        return(out)
      }
    }
    return(out)
  } else
  {
    out <- execute.cli("varsum.test")
    return(out)
  }
}