vector.prompt <- function(prompt=NULL)
{
  if (missing(prompt))
  {
    prompt = "Building a vector: "
  }
  
  writeLines("")
  writeLines("You can create your own vector, load from a file, or use one in the global environment. ")
  writeLines("")
  writeLines(paste("For this vector: ", prompt, sep = ""))
  
  how = readline("Do you want to create your own, load from a csv file, or use one in the global environment (C/L/G)? ")
  cat("\014")
  while (how != "C" && how != "L" && how != "G")
  {
    writeLines("There is a typo.")
    how = readline("Create your own vector, load from a csv, or use one in the global environment (C/L/G)? ")
  }
  
  writeLines("")
  
  if (how == "G")
  {
    global = TRUE
    while (global)
    {
      out <- global.env(prompt)
      for (i in seq(length(out))) #make sure we loaded a numeric vector
      {
        if (is.logical(out)) # if we failed to get the global value or it was false
        {
          if (out == FALSE)
          { 
            manual = TRUE
            global = FALSE
            break
          }
        }
        
        if (!is.numeric(out[i]) || is.na(out[i])) # if a certain element is not a number
        {
          writeLines("The value is not a numeric vector.")
          global = logical.prompt("Do you want to try again? ")
          writeLines("")
          if (global == TRUE) #we are going to try again, so keep manual off
          {
            manual = FALSE
          } else #we are quitting, so we need to manually make this thing, loop already is false
          {
            manual = TRUE
          }
          break
        } else #no problems, quit the loop and don't make it manually
        {
          manual = FALSE
          global = FALSE
        }
      } #### End for loop
      
      if (global == FALSE && manual == FALSE) ## we are ready to report results
      {
        return(out)
      } else if (manual == TRUE) ## we need to make a vector
      {
        break
      }
    }
  } else if (how == "L")
  {
    loop = TRUE
    while(loop)
    {
      out <- csv.prompt(prompt)
      if (!is.data.frame(out))
      {
        loop = logical.prompt("A problem occured. Do you want to try again? ")
        if (loop == FALSE)
        {
          manual = TRUE
        }
      } else
      {
        manual = FALSE
        
        x = vector()
        
        #convert the data frame to a vector
        for (i in seq(length(out[[1]])))
        {
          x[i] = out[[1]][i]
        }
        rm(out) #clear out so we can store x into it
        
        out = x
        
        break
      }
    }
  } 
  
  if (how == "C" || manual == TRUE)
  {
    loop = TRUE
    while (loop)
    {
      writeLines("Enter data as a list of comma separated values.")
      writeLines(prompt)
      out <- readline("Enter comma separated values: ") #get the string
      out = strsplit(out, ",") #split the string
      out = unlist(out) #make it so we can play with it
      out = as.numeric(out) #turn it into numbers
      for (i in seq(length(out)))
      {
        if (is.na(out[i])) #check for any failed number conversions
        {
          loop = TRUE
          writeLines("There is a typo: a numeric conversion failed. ")
          break
        } else
        {
          loop = FALSE
        }
      }
    }
  }
  writeLines("")
  return(out)
}