\name{HypoTest-package}
\alias{HypoTest-package}
\docType{package}
\title{Hypothesis Testing with Interactive User Input}
\description{
This package provides an assortment of functions, once found in various packages, frequently used to perform Hypothesis tests
and confidence interval construction, all under one package. In addition, both graphical and textual user interface functions are provided to make using these functions user friendly. 
Also, the functions that support these user interfaces are provided, which may aid the user in processing strings;
constructing vectors, matricies and factors; and loading comma separated value files and dataframes.
Currently, the graphical user interface is in beta development.
}
\details{
\tabular{ll}{
Name: \tab HypoTest\cr
Version: \tab 0.5.0.0\cr
Date: \tab July 31, 2015\cr
License: \tab GPL \cr
}
}

\value{
The following graphical user interface functions may be called by the user. Graphics is provided by the tcltk package.

\item{\link[HypoTest]{HypoTest}}{The core of HypoTest. By default, this launches the graphical interface. Call this function to get started. You can also call HypoTest(\code{FALSE}) to launch the more powerful command line interface functions.}
\item{\link[HypoTest]{execute.gui}}{Grpahical User Interface. Makes all GUI function calls.}


The following is a list of all of the graphical statistical functions that may be called by the user. These functions take no arguments when called, but does take information in a graphical window. This information is then passed to the non-graphical statistics functions in non-interactive mode, listed furthur down this page.

\item{\link[HypoTest]{binom.test.gui}}{Graphical User Interface for binom.test.}
\item{\link[HypoTest]{chisq.test.gui}}{Graphical User Interface for chisq.test.}
\item{\link[HypoTest]{goodfit.predict.gui}}{Graphical User Interface for goodfit.predict.}
\item{\link[HypoTest]{ks.test.gui}}{Graphical User Interface for ks.test.}
\item{\link[HypoTest]{mcnemar.test.gui}}{Graphical User Interface for mcnemar.test.}
\item{\link[HypoTest]{prop.test.gui}}{Graphical User Interface for prop.test.}
\item{\link[HypoTest]{sigma.test.gui}}{Graphical User Interace for sigma.test.}
\item{\link[HypoTest]{sigmasum.test.gui}}{Graphical User Interface for sigmasum.test.}
\item{\link[HypoTest]{t.test.gui}}{Graphical User Interface for t.test.}
\item{\link[HypoTest]{tsum.test.gui}}{Graphical User Interface for tsum.test.}
\item{\link[HypoTest]{var.test.gui}}{Graphical User Interface for var.test.}
\item{\link[HypoTest]{varsum.test.gui}}{Graphical User Interace for varsum.test.}
\item{\link[HypoTest]{z.test.gui}}{Graphical User Interface for z.test.}
\item{\link[HypoTest]{zsum.test.gui}}{Graphical User Interface for zsum.test.}


The following functions are intended to be called by the graphical user interface functions in this package, but may be called by the user if the user has some use for string input processing. In addition to the reported return values, all of these functions return a logical that says if the input values conform to the expected input (that is, integer.gui will return TRUE if the user puts in an integer, FALSE otherwise). The return value is in the form of a list.

\item{\link[HypoTest]{alternative.gui}}{Returns either "greater", "less", or "two.sided".}
\item{\link[HypoTest]{conf.level.gui}}{Returns a number between 0 and 1.}
\item{\link[HypoTest]{integer.gui}}{Returns an integer.}
\item{\link[HypoTest]{integer.optional.gui}}{Returns an integer. Logical only evaluated if data present or if optional dependency has data presnet.}
\item{\link[HypoTest]{logical.gui}}{Returns a logical.}
\item{\link[HypoTest]{logical.optional.gui}}{Returns a logical. Logical only evaluated if data present or if optional dependency has data presnet.}
\item{\link[HypoTest]{numeric.gui}}{Returns a number.}
\item{\link[HypoTest]{numeric.optional.gui}}{Returns a number. Logical only evaluated if data present or if optional dependency has data presnet.}
\item{\link[HypoTest]{vector.gui}}{Retuns a numeric vector.}
\item{\link[HypoTest]{vector.optional.gui}}{Returns a numeric vector. Logical only evaluated if data present or if optional dependency has data presnet.}



The following command line interactive functions may be called by the user.

\item{\link[HypoTest]{interactive.cli}}{The main command line user interface. Picks the correct statistical test.}
\item{\link[HypoTest]{execute.cli}}{Once a function is picked, this executes the statistics test in command line mode.}


The following is a list of all of the command line statistical functions that may be called by the user. Without any arguments, these functions will enter interactive mode.

\item{\link[HypoTest]{aov}}{Interface for Analysis of Variance Model}
\item{\link[HypoTest]{binom.test}}{Interface for Exact Binomial Test}
\item{\link[HypoTest]{chisq.test}}{Interface for Pearson's Chi-squared Test for Count Data}
\item{\link[HypoTest]{goodfit.predict}}{Interface for Goodness-of-fit Tests for Discrete Data}
\item{\link[HypoTest]{ks.test}}{Interface for Kolmogorov-Smirnov Tests}
\item{\link[HypoTest]{lm}}{Interface for Fitting Linear Models}
\item{\link[HypoTest]{mcnemar.test}}{Interface for McNemar's Chi-squared Test for Count Data}
\item{\link[HypoTest]{prop.test}}{Interface for Test of Equal or Given Proportions}
\item{\link[HypoTest]{sigma.test}}{Interface for Population Variance Hypothesis Test}
\item{\link[HypoTest]{sigmasum.test}}{Interface for Summarized Population Variance Test}
\item{\link[HypoTest]{t.test}}{Interface for Student's t-Test}
\item{\link[HypoTest]{tsum.test}}{Interface for Summarized t-Test}
\item{\link[HypoTest]{var.test}}{Interface for F Test to Compare Two Variances}
\item{\link[HypoTest]{varsum.test}}{Interface for Summarized F Test to Compare Two Variances}
\item{\link[HypoTest]{z.test}}{Interface for Z-Test}
\item{\link[HypoTest]{zsum.test}}{Interface for Summarized z-Test}


The following functions are intended to be used by the command line interactive functions in this package, but may be called by the user if the user has some use for string input processing.
\item{\link[HypoTest]{alternative.prompt}}{Returns either "greater", "less", or "two.sided".}
\item{\link[HypoTest]{conf.level.prompt}}{Returns a number between 0 and 1.}
\item{\link[HypoTest]{csv.prompt}}{Returns a csv as a value or \code{FALSE}.}
\item{\link[HypoTest]{dataframe.prompt}}{Returns a data frame or \code{FALSE}.}
\item{\link[HypoTest]{factor.prompt}}{Returns a factor.}
\item{\link[HypoTest]{global.env}}{Returns a value found in the global environment or \code{FALSE}.}
\item{\link[HypoTest]{integer.prompt}}{Returns an integer.}
\item{\link[HypoTest]{logical.prompt}}{Returns a logical.}
\item{\link[HypoTest]{matrix.prompt}}{Returns a numeric matrix.}
\item{\link[HypoTest]{numeric.prompt}}{Returns a number.}
\item{\link[HypoTest]{vector.prompt}}{Retuns a numeric vector.}

}
\author{
Programmer and Documentation Author: James Palmer

Maintainer:  Dr. Lenin # Email: rblenin@uca.edu
}

\seealso{
You can see an overview of the command line functions with this pdf: \url{../doc/flowchart.pdf}.
A change log can be found here: \url{../NEWS}
}

\keyword{package}
