\name{binom.test}
\alias{binom.test}
\title{Interface for Exact Binomial Test}
\description{
  User friendly implementation of \code{\link[stats]{binom.test}}.
  Performs an exact hypothesis test about the
  probability of success in a Bernoulli experiment.
}
\usage{
# binom.test()

binom.test(x,
           n=NULL,
           p = 0.5,
           alternative = "two.sided",
           conf.level = 0.95,
           interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{a single number representing the nuber of successes in an experiment,
    or a vector of length 2 that first gives the number of successes
    and then gives the number of failures in an experiment.}
  \item{n}{a single number representing the number of trials;
    ignored if you give both successes and failures in \code{x}
    (that is, \code{x} has length 2).}
  \item{p}{a single number between 0 and 1 representing the
    hypothesized probability of success.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{binom.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the 1 proportion z test statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the probability of success.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{binom.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}

\seealso{
  \code{\link[stats]{binom.test}} for the function that implements the
  test.
}
\examples{
## Example 5.2.1 from Essentials of Mathematical Statistics
## A student claims that 25\% of plain M&M candies are red.
## A random sample of 195 candies contains 37 red candies.
## Use these data to test the claim at the 0.05 significance level.

## Parameters
## The first sentence tells us that p = 0.25.
## The scond sentence tells us that x = 37 and n = 195.
## We want to know if there are fewer than 25\% red candies,
## therefore the alternative = "less".
## Last, 0.05 signficance level corresponds to alpha.
## The confidence level is 1 - alpha, so conf.level = 0.95.

## Method 1
out <- binom.test(37, 195, p = 0.25, alternative = "less", conf.level = 0.95)

## Method 2
## Instead of using x = 37, n = 195, we can use x = c(success, failure).
## Thus, x = c(37, 195 - 37), which is x = c(37, 158).
## Note that n is not required if we enter a vector of two values for x.
out <- binom.test(x=c(37, 158), p = 0.25, alternative = "less")

## Results
## The results for this example are:
## out$test.statistic = -1.943211
## out$p.value = 0.02873216
## out$alternative = "less"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 0.000000 0.241936

}
\keyword{htest}
