\name{execute.cli}
\alias{execute.cli}
\alias{function.execute.cli}
\title{
Interactive Function Execution (Command Line Interface)
}
\description{Based on the provided function name, assists the user
in providing appropriate arguments and passing them to the function.
Previously called function.execute.cli.
}
\usage{
execute.cli(name = NULL)

function.execute.cli(name = NULL)
}
\arguments{
  \item{name}{a character vector or \code{NULL} which represents the name of the function.
  The format of the name should be the same name as the file name which holds the function,
  minus the file extension. For example, a t-test with summary statistics should have the
  name \code{\link{tsum.test}}.}
}
\details{
Prompts the user for appropriate input based on the \code{name}. If \code{name} is not given,
control will be transferred to \link{interactive.cli}, which will prompt for information until
enough is provided to execute the appropriate function.
}
\value{
  Will return the results of the called function.
  Upon user exit, the return value will be the results of the last statistical function called.
  Unless an unsupported function is called, the
  output will be a list that typically, but does not always, contains the following components:
  
  \item{test.statistic}{the test statistic of the specific test.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and the \code{conf.level}.}
  \item{conf.int}{a confidence interval for the probability of success.}
  
  In addition, other components may include the critical value, degrees of freedom, residuals,
  or a \code{\link[vcd]{goodfit}} object.
  
  May return an object of class "try-error" if an error is encountered in an executed function that
  returns an object of class "try-error". The user will be asked to try again if this occurs. If the
  user declines to try again, the "try-error" object is returned.
}
\seealso{
\link{interactive.cli} for the other command line interface that gathers the necessary information
from the user to determine the appropriate statistical test.
You can see an overview of the functions with this pdf: \url{../doc/flowchart.pdf}.
}
\examples{
## For an example, please see the help documentation for interactive.cli.

}
\keyword{interactive}
