\name{goodfit.predict}
\alias{goodfit.predict}
\alias{goodfit}
\title{Interface for Goodness-of-fit Tests for Discrete Data}
\description{
  User friendly implementation of \code{\link[vcd]{goodfit}}.
  Also performs predictions on the goodfit results.
  Fits a discrete (count data) distribution for goodness-of-fit tests.
}
\usage{
# goodfit.predict()

goodfit.predict(x,
                type = c("poisson", "binomial", "nbinomial"),
                method = c("ML", "MinChisq"), 
                par = NULL, 
                newcount = NULL,
                predict.type = c("response", "prob"),
                interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode. Interactive mode does not support tables.
  \item{x}{either a vector of counts, a 1-way table of frequencies of
    counts or a data frame or matrix with frequencies in the first
    column and the corresponding counts in the second column.}
  \item{type}{a character string indicating which distribution should be
    fit (for \code{goodfit}) or  indicating the type of prediction
    (fitted response or probabilities in \code{predict}) respectively.}
  \item{method}{a character string indicating whether the distribution
    should be fit via ML (Maximum Likelihood) or Minimum Chi-squared.}
  \item{par}{a named list giving the distribution parameters (named as
    in the corresponding density function), if set to \code{NULL}, the
    default, the parameters are estimated.  If the parameter \code{size}
    is not specified if \code{type} is \code{"binomial"} it is taken to
    be the maximum count. If \code{type} is \code{"nbinomial"}, then
    parameter \code{size} can be specified to fix it so that only the
    parameter \code{prob} will be estimated (see the examples below).}
  \item{newcount}{a numeric argument to be passed to \code{\link{predict}}.
  Has the effect of selecting which fitted value to return by element.}
  \item{predict.type}{a character string argument to be passed to
  \code{\link{predict}}. If "response", will return the fitted value.
  If "prob", will return the probability.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
 Takes the above input parameters and passes them to \code{\link[vcd]{goodfit}}.
 Also runs \code{\link[stats]{predict}} on the results of \code{\link[vcd]{goodfit}}.
 Will return a list with the following values.
}
\value{
  A list with elements:
  \item{goodfit}{A list of class "goodfit" with these elements (ends at "par"):}
    \item{observed}{observed frequencies}
    \item{count}{corresponding counts}
    \item{fitted}{expected frequencies fitted by ML}
    \item{type}{a character string indicating the distribution fitted}
    \item{method}{a chatacter string indicating the fitting method}
    \item{df}{degrees of freedom}
    \item{par}{a named list of the estimated distribution parameters}
  \item{}{}
  \item{}{}
  \item{predict}{The results of the \code{\link[stats]{predict}} function
  with the \code{goodfit} object as its argument}
  
  Will return an object of class "try-error" if an error is encountered in 
  either \code{\link[vcd]{goodfit}} or \code{\link[stats]{predict}}.
}

\seealso{
  \code{\link[vcd]{goodfit}} for the function that implements the
  goodness-of-fit-test.
  \code{\link[stats]{predict}} for the function that implements the
  prediction on the goodness-of-fit object.
}

\examples{
## Simulated data example

## Data
dummy <- rnbinom(200, size = 1.5, prob = 0.8)

## Method
out <- goodfit.predict(dummy, type = "nbinomial", method = "MinChisq")

## Results
## out$goodfit
##
## Observed and fitted values for nbinomial distribution
## with parameters estimated by `MinChisq' 
##
##  count observed     fitted
##     0      143 142.265766
##     1       45  46.630479
##     2       11   9.378819
##     3        1   1.490458
##
## out$predict
## 142.265766  46.630479   9.378819   1.490458

## Method
out <- goodfit.predict(dummy, type = "nbinomial", method = "MinChisq", newcount = 0)

## Predict Results
## out$predict
## 142.265766

## Method
out <- goodfit.predict(dummy, type = "nbinomial", method = "MinChisq",
newcount = 0, predict.type = "prob")

## Predict Results
## out$predict
## 0.71132883
}

\keyword{htest}