\name{ks.test}
\alias{ks.test}
\title{Interface for Kolmogorov-Smirnov Tests}
\description{
  User friendly implementation of \code{\link[stats]{ks.test}}. Perform a one- or two-sample Kolmogorov-Smirnov test.
}
\usage{
# ks.test()

ks.test(x, 
        y,
        \dots,
        alternative = "two.sided", 
        conf.level = 0.95,
        exact = NULL,
        interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{a numeric vector of data values.}
  \item{y}{either a numeric vector of data values, or a character string
    naming a cumulative distribution function or an actual cumulative
    distribution function such as \code{pnorm}.  Only continuous CDFs
    are valid.}
  \item{\dots}{parameters of the distribution specified (as a character
    string) by \code{y}.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{exact}{\code{NULL} or a logical indicating whether an exact
    p-value should be computed. Not available in the two-sample case for a one-sided
    test or if ties are present.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{ks.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the Kolmogorov-Smirnov test statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{ks.test}}.
}

\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}

\seealso{
  \code{\link[stats]{ks.test}} for the function that implements the
  test.
}
\examples{
## Example 5.7.4 from Essentials of Mathematical Statistics
## Table 5.12 shows the times spent waiting in line at a grocery store
## (in minutes) of 30 different customers. we test the claim that X,
## the amount of time a randomly selected custome spends waiting in
## line, has an exponential distribution.

## Data
data = c(0.03, 0.21, 0.33, 0.66, 0.91, 1.33, 1.56, 1.84, 2.74, 3.46,
0.04, 0.21, 0.36, 0.87, 0.92, 1.4, 1.6, 1.87, 2.79, 3.9,
0.1, 0.22, 0.47, 0.9, 0.96, 1.51, 1.76, 2.36, 3.24, 4.25)

## Parameters
## The x parameter is simply our data above. We are testing if this is
## an exponential distribution, so the next argument is going to be
## "pexp". Lastly, the parameter lambda is 1 divided by the mean of
## our data (page 403 of the text). This is our last argument to pass.
## We could change the confidence level, but we will leave it at the
## default.

## Method
out <- ks.test(data, "pexp", 1/mean(data))

## Results
## out$test.statistic = 0.1232142
## out$p.value = 0.7525548
## out$alternative = "two.sided"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## Warning message:
## In function (x, y, ..., alternative = c("two.sided", "less",
## "greater"), : ties should not be present for the Kolmogorov-
## Smirnov test

## Note that the test statistic is computed differently here than
## in the textbook.
}
\keyword{htest}
