\name{mcnemar.test}
\alias{mcnemar.test}
\title{Interface for McNemar's Chi-squared Test for Count Data}
\description{
  User friendly implementation of \code{\link[stats]{mcnemar.test}}.
  Performs McNemar's chi-squared test for symmetry of rows and columns
  in a two-dimensional contingency table.
}
\usage{
# mcnemar.test()

mcnemar.test(x,
             y = NULL,
             correct = TRUE,
             conf.level = 0.95,
             interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{either a two-dimensional contingency table in matrix form,
    or a factor object.}
  \item{y}{a factor object; ignored if \code{x} is a matrix.}
  \item{correct}{a logical indicating whether to apply continuity
    correction when computing the test statistic.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{mcnemar.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the value of McNemar's test statistic.}
  \item{p.value}{the p-value of the test.}
  \item{alternative}{a character string that reads "Probabilities are not the same".}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{mcnemar.test}}.
}
\references{
Alan agresti (1990). \emph{Categorical Data Analysis}. New York: Wiley. Pages 350-354
}
\seealso{
  \code{\link[stats]{mcnemar.test}} for the function that implements the
  test.
}

\examples{
## Example from Agresti (1990), p. 350.
## Approval of the President's performance in office in two surveys,
## one month apart, for a random sample of 1600 voting-age Americans.

## Data
Performance =
matrix(c(794, 86, 150, 570),
       nrow = 2,
       dimnames = list("1st Survey" = c("Approve", "Disapprove"),
                       "2nd Survey" = c("Approve", "Disapprove")))
## Parameters
## We only need the matrix of information.

## Method
out <- mcnemar.test(Performance)

## Results
## out$test.statistic = 16.8178
## out$p.value = 4.114562e-05
## out$alternative = "Probabilities are not the same"
## out$decision = "Reject Null (accept alternative)"
## out$df = 1
}
\keyword{htest}
