\name{sigma.test}
\alias{sigma.test}
\title{Interface for Population Variance Hypothesis Test}
\description{
  Performs hypothesis test and confidence interval on a population variance.
}
\usage{
# sigma.test()

sigma.test(x, 
           s = 1, 
           sigmasq = s^2,
           alternative = "two.sided",
           conf.level = 0.95,
           interactive = FALSE)
}

\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{a numeric vector containing the data. }
  \item{s}{sample standard deviation. }
  \item{sigmasq}{hypothesized population variance. }
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Implements a chi-squared test to test the population variance.
}
\value{
  A list containing the following
  components:
  \item{test.statistic}{the value of the test statistic. }
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the population variance.}
  \item{critical.value}{the critical value for the chi-squared test.}
  
  Will return an object of class "try-error" if an error is encountered in
  the internal funciton \code{sigma.test.function}.
  
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
\code{\link{sigmasum.test}} for the same test using summary statistics
}
\examples{
## Exercise 3 on Page 298 from Essentials of Mathematical Statistics
## The mass (in grams) of 17 randomly selected yellow M&M candies is shown
## in the table below (data collected by Frank Ohlinger, 2009). Use the
## data to calculate a 99\% confidence interval estimate of the standard
## deviation of the mass of all such candies (assume the population is
## normally distributed).

## Data
candy <- c(0.89, 0.89, 0.85, 0.86, 0.9, 0.83, 0.82, 0.86, 0.94,
0.83, 0.84, 0.88, 0.86, 0.97, 0.82, 0.8, 0.76)

## Parameters
## While we could use the sigma and sigmasq parameters if we were testing
## a hypothesis, we do not need them for simply constructing a confidence
## interval. The confidence level is 0.99.

## Method
out <- sigma.test(candy, conf.level = 0.99)

## Results
## out$test.statistic = 16
## out$p.value = 0.9059216
## out$alternative = "two.sided"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = 0.466919 3.111505
## out$critical.value = 5.142205 34.267187

## Modified Exercise 3
## Suppose we also want to test the claim that the population standard
## deviation is less than 0.5.

## Paramaters
## In addition to the data values, we add that sigma = 0.5 and that
## alternative = "lesser".

## Method
out <- sigma.test(candy, sigma = 0.5, alternative = "less", conf.level = 0.99)

## Results
## out$test.statistic = 16
## out$p.value = 0.5470392
## out$alternative = "less"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = 0.1167297 0.7778763
## out$critical.value = 5.812212
}
\keyword{htest}
