\name{sigmasum.test}
\alias{sigmasum.test}
\title{Interface for Summarized Population Variance Test}
\description{
  Performs hypothesis test and confidence interval on a population variance using summary statistics.
}
\usage{
# sigmasum.test()

sigmasum.test(n,
              s = 1,
              sigmasq = s ^ 2,
              alternative = "two.sided",
              conf.level = 0.95,
              interactive = FALSE)
}

\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{n}{a number contaning the size of the sample. }
  \item{s}{sample standard deviation. }
  \item{sigmasq}{hypothesized population variance. }
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Implements a chi-squared test to test the population variance using summary statistics.
}
\value{
  A list containing the following
  components:
  \item{test.statistic}{the value of the test statistic. }
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the population variance.}
  \item{critical.value}{the critical value for the chi-squared test.}
  
  Will return an object of class "try-error" if an error is encountered in 
  the internal function \code{sigmasum.test.function}.
  
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
\code{\link{sigma.test}} for the same test using data
}
\examples{
## Exercise 1 on Page 297 from Essentials of Mathematical Statistics
## Suppsoe that a sample of 26 steel sheets of a certain type was tested for
## tensile strength (measured in kilograms per square millimeter), and the
## variance was 2.41. Use these data to construct a 90\% confidence interval of
## the population variance (assume the population is normally distributed).
## If the requirements for production of these sheets state that the variance
## must be less than 3.5, does it appear that the sheets meet specifications?

## Paramaters
## The sample size is n = 26, the hypothesised variance is 3.5 (so the standard
## deviation is 1.87), and the alternative hypothesis is "less".

## Method
out <- sigmasum.test(n = 26, sigma = 1.87, alternative = "less", conf.level = 0.9)

## Results
## out$test.statistic = 7.149189
## out$p.value = 0.0001819075
## out$alternative = "less"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 2.321826 5.983168
## out$critical.value = 16.47341
}
\keyword{htest}
