\name{t.test}
\alias{t.test}
\title{Interface for Student's t-Test}
\description{
  User friendly implementation of \code{\link[stats]{t.test}}. Performs one and two sample t-tests on vectors of data.
}
\usage{
# t.test()

t.test(x,
       y = NULL,
       mu = 0,
       alternative = "two.sided",
       paired = FALSE,
       var.equal = FALSE,
       conf.level = 0.95,
       interactive = FALSE)

}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{a numeric vector of data values.}
  \item{y}{an optional numeric vector of data values.}
  \item{mu}{a number indicating the true value of the mean (or
    difference in means if you are performing a two sample test).}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{paired}{a logical indicating whether you want a paired
    t-test. Should be \code{TRUE} for dependent data.}
  \item{var.equal}{a logical variable indicating whether to treat the
    two variances as being equal. If \code{TRUE} then the pooled
    variance is used to estimate the variance otherwise the Welch
    (or Satterthwaite) approximation to the degrees of freedom is used.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{t.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the value of the t-statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the mean appropriate to the
    specified alternative hypothesis.}
  \item{critical.value}{the critical interval of the t test.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{t.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
  \code{\link[stats]{t.test}} for the function that implements the
  test.
}
\examples{
## Exercise 9 on Page 363 from Essentials of Mathematical Statistics
## To examine the savings when purchasing generic brand products at
## a large retailer, a student records the prices of 10 different,
## randomly selected name brand products and the prices of a
## corresponding generic equivalent, as shown in the the table below
## (data collected by Amanda Schoreder, 2010)
## a. For each product, calculate the percentage of savings experienced
## when the generic brand product is purchased instead of the name brand.
## b. Test the claim that the mean savings is greater than 20\%.

## Data
name_brand = c(7.68, 9.56, 7.62, 1.58, 2.98, 3.58, 6.54, 8.97, 4.06, 6.46)
generic_bd = c(4.47, 2.97, 3.34, 0.67, 3.12, 2.98, 5.34, 6.97, 1.76, 4.12)
savings = 100 - generic_bd /name_brand * 100 ## same as (name_brand-generic_bd)/name_brand * 100

## Parameters
## Since this is a 1 sample example, we will not use the
## y, paired, or var.equal arguments.
## Part a is done when calculating "savings", which will be used
## as the "x" parameter. Since we want to know if savings is greater
## than 20 percent, mu = 20 and alternative = "greater".
## By default, conf.level = 0.95.

## Method
out <- t.test(savings, mu = 20, alternative = "greater")

## Results
## out$test.statistic = 2.297099
## out$p.value = 0.0236115
## out$alternative = "greater"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 23.43527 Inf
## out$critical.value = 1.833113

## Example 5.6.3
## At a large university, freshman students are required to take an
## introduction to writing class. Students are given a survey on their
## attitudes toward writing at the beginning and end of each class.
## A score between 0 and 100 is assigned to each student, based on their
## survey, where the higher the score suggests a more favorable attitude
## towards writing. The scores of 9 different students are shown in Table
## 5.6. Test the claim that the scores improve from the beginning to the
## end. These data are said to come in "matched pairs" (each of the
## nine students provides two numbers, a beginning score and an end score).

## Data
begin = c(77.6, 86.1, 62.1, 93.1, 74.6, 42, 86.9, 79.3, 80.2)
end = c(85.4, 83.2, 64.2, 96.6, 79.3, 40.5, 87.2, 89.2, 85.6)

## Parameters
## While the samples of scores come from the same set of students, there are
## two samples here. To indicate that the two samples come from the same people
## we set paired = TRUE. Note that if the score improves, it is higher at the
## end than at the beginning. Thus, if we want to use the alternative hypothesis
## "greater", we need to make x = end and y = begin. Otherwise, we should use
## an alternative hypothesis of "less".

## Method 1
## Alternative = "greater"
out <- t.test(x = end, y = begin, alternative = "greater", paired = TRUE)

## Results
## out$test.statistic = 2.317183
## out$p.value = 0.02456751
## out$alternative = "greater"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 0.6429602 Inf

## Method 2
## Alternative = "less"
out <- t.test(x = begin, y = end, alternative = "less", paired = TRUE)

## Results
## out$test.statistic = -2.317183
## out$p.value = 0.02456751
## out$alternative = "less"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = -Inf -0.6426902
}
\keyword{htest}
