\name{tsum.test}
\alias{tsum.test}

\title{Interface for Summarized t-Test}
\description{User friendly implementation of \code{\link[PASWR]{tsum.test}}.
Performs a one-sample, two-sample, or a Welch modified two-sample 
t-test based on user supplied summary information.
}
\usage{
# tsum.test()

tsum.test(n.x,
          mean.x,
          s.x,
          n.y = NULL,
          mean.y = NULL,
          s.y = NULL,
          mu = 0,
          alternative = "two.sided", 
          var.equal = FALSE,
          conf.level = 0.95,
          interactive = FALSE)
}

\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{n.x}{a single number representing the sample size for \code{x}}
  \item{mean.x}{a single number representing the sample mean of \code{x}}
  \item{s.x}{a single number representing the sample standard deviation for \code{x}}
  \item{n.y}{a single number representing the sample size for \code{y}}
  \item{mean.y}{a single number representing the sample mean of \code{y}}
  \item{s.y}{a single number representing the sample standard deviation for \code{y}}
  \item{mu}{is a single number representing the value of the mean or difference in means 
  specified by the null hypothesis.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{var.equal}{logical flag: if \code{TRUE}, the variances of the parent populations 
  of \code{x} and \code{y} are assumed equal. Argument \code{var.equal} should be supplied 
  only for the two-sample tests.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}

\details{
Takes the above input parameters and passes them to \code{\link[PASWR]{tsum.test}}.
  Will return a list with the following values.
}

\value{
  A list containing the following components:
  
  \item{test.statistic}{the t-statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int }{is a confidence interval for the true mean or difference in means.} 
  \item{df}{the degrees of freedom of the t-distribution.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[PASWR]{tsum.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{ 
\code{\link[PASWR]{tsum.test}} for the function that implements the
  test.
}
\examples{
## Example 5.3.3 from Essentials of Mathematical Statistics
## A manufacturer of cheese claims that the mean weight of all
## its 12-oz packages of shredded cheddar is greater than 12 oz.
## They collect a random sample of n = 36 packages, weigh each,
## calculate a sample mean of x bar = 12.05 and a sample standard
## deviation of s = 0.15. Use these data to test the claim at the
## 0.05 significance level.

## Parameters
## Since this is a 1 sample example, we will not use the
## n.y, mean.y, sigma.y, or var.equal arguments.
## We are given directly that n.x = 36, mean.x = 12.05, and
## s.x = 0.15. The claim is that mu is greater than 12, thus
## mu = 12 and alternative = "greater".
## A 0.05 significance level is equivalent to the 0.95 confidence
## level, so conf.level = 0.95.

## Method
out <- tsum.test(n.x = 36, mean.x = 12.05, s.x = 0.15, mu = 12, alternative = "greater")

## Results
## out$test.statistic = 2
## out$p.value = 0.02665383
## out$alternative = "greater"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 12.00776 Inf
## out$df = 35

## Example 5.6.1
## To compare two different diets A and B, volunteers follwed each diet
## for 6 months. Among the 10 who followed diet A, their mean weight loss
## was 4.5 lb with a standard deviation of 6.5 lb. Among the 10 who
## followed diet B, their mean weight loss was 3.2 lb with a standard
## deviation of 4.5 lb. Assuming both populations are normally distributed
## and have the same variance, test the claim that the mean weight loss
## on diet A is higher than that on diet B.

## Paramaters
## We know the number of people in each diet is 10, so n.x = n.y = 10.
## We also know their means and standard deviations. We are assuming
## that both populations have the same variance, so var.equal = TRUE.
## Because we want to know if people on diet A lost more weight than,
## diet B, alternative = "greater".

## Method
out <- tsum.test(n.x = 10, mean.x = 4.5, s.x = 6.5, n.y = 10, mean.y = 3.2,
s.y = 4.5, alternative = "greater", var.equal = TRUE)

## Results
## out$test.statistic = 0.52
## out$p.value = 0.3047001
## out$alternative = "greater"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = -3.035159 Inf
## out$df = 18
}
\keyword{htest}
