\name{var.test}
\alias{var.test}
\title{Interface for F Test to Compare Two Variances}
\description{
  User friendly implementation of \code{\link[stats]{var.test}}. Performs an F test to compare the variances of two samples from normal populations.
}
\usage{
# var.test()

var.test(x,
         y,
         ratio = 1,
         alternative = "two.sided",
         conf.level = 0.95,
         interactive = FALSE)

}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x, y}{numeric vectors of data values.}
  \item{ratio}{the hypothesized ratio of the population variances of
    \code{x} and \code{y}.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{var.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the value of the F test statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the ratio of the population
    variances.}
  \item{df}{the degrees of freedom of x and y.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{var.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
  \code{\link[stats]{var.test}} for the function that implements the
  test.
}
\examples{
## Exercises 8-9 on page 382-383 from Essentials of Mathematial Statistics
## 8. A student constructs a experiment where she starts a stopwatch
## and asks a fellow student to tell her when 30 sec has passed. She
## then stops the watch and records how mch time has actually passed.
## The times (in seconds) for 15 male and 15 female students are shown
## in the table below (data collected by Courtney Cale, 2011). Assuming
## that the populations are normally distributed, perform an F-test
## to determine if it is reasonable to assume that the populations
## have the same variance.
## 9. Construct a 95\% confidence interval estimate of the ratio of the
## population variances using the data in exercise 8 above.

## Data
males = c(18.6, 28.7, 21.6, 30.5, 24.0, 37.8, 15.5, 30.6,
16.3, 51.4, 47.3, 38.9, 26.6, 21.4, 16.4)
females = c(30.6, 29.7, 41.5, 25, 23.3, 26.5, 37.0, 18.8,
38.4, 22.7, 28.3, 40.9, 36.1, 19.8, 30.7)

## Parameters
## We set x = males and y = females. Because we are testing to see if the
## two samples have the same variance, ratio = 1 (since a/b = 1 if a = b).
## The confidence level is 95\% and the alternative hypothesis is the
## default, "two.sided".

## Method 1
out <- var.test(males, females, ratio = 1, alternative = "two.sided", conf.level = 0.95)

## Results
## out$test.statistic = 2.272717
## out$p.value = 0.1365659
## out$alternative = "two.sided"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = 0.7630183 6.7694855
## out$df = 14 14

## Method 2
## For a "two.sided", ratio = 1 test we can
## switch the order of the input without
## changing anything else
out <- var.test(females, males)

## Results
## Note that this test statistic is the inverse of Method 1's test statistic
## out$test.statistic = 0.4400021
## out$p.value = 0.1365659
## out$alternative = "two.sided"
## out$decsion = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = 0.1477217 1.3105846
## out$df = 14 14
}
\keyword{htest}
