\name{varsum.test}
\alias{varsum.test}
\title{Interface for Summarized F Test to Compare Two Variances}
\description{
  Performs an F test to compare the variances of two samples from normal
  populations using summary statistics.
}
\usage{
# varsum.test()

varsum.test(n.x,
            s.x,
            n.y,
            s.y,
            ratio = 1,
            alternative = "two.sided",
            conf.level = 0.95,
            interactive = FALSE)

}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{n.x, n.y}{the sample sizes of x and y.}
  \item{s.x, s.y}{the sample standard deviations of x and y.}
  \item{ratio}{the hypothesized ratio of the population variances}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Implements an F-test to test the ratio of two variances using summary statistics
}
\value{
  A list containing the following components:
  \item{test.statistic}{the value of the F test statistic.}
  \item{p.value}{the p-value of the test.}
  \item{conf.int}{a confidence interval for the ratio of the population
    variances.}
    
  Will return an object of class "try-error" if an error is encountered in
  the internal function \code{varsum.test.function}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
  \code{\link{var.test}} for the same test using data
}
\examples{
## Exercise 4 on Page 381 from Essentials of Mathematical Statistics
## A sample of 23 bluegill from a certain lake has a mean weight of
## 1.25 lb with a standard deviation of 0.15 lb while a sample of 18 catfish
## from the same lake has a mean weight of 4.36 lb with a standard deviation
## of 1.02 lb. Assuming that both populations are normally distributed, use
## an F-test to determine if the two populations have the same variance at
## the 99\% confidence level.

## Parameters
## We know that n.x = 23, s.x = 0.15, n.y = 18, s.y = 1.02. we do not need
## the means to test if the variances are equal. We also know that ratio = 1
## (since a/b = 1 if a=b), alternative = "two.sided", and conf.level = 0.99.

## Method 1
out <- varsum.test(n.x = 23, s.x = 0.15, n.y = 18, s.y = 1.02, ratio = 1,
alternative = "two.sided", conf.level = 0.99)

## Results
## out$test.statistic = 0.0216263
## out$p.value = 4.987951e-13
## out$alternative = "two.sided"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 0.006083064 0.070821344

## Method 2
## For a "two.sided", ratio = 1 test we can
## switch the order of the input without
## changing anything else
out <- varsum.test(18, 1.02, 23, 0.15, conf.level = 0.99)

## Results
## Note that this test statistic is the inverse of Method 1's test statistic
## out$test.statistic = 46.24
## out$p.value = 4.987951e-13
## out$alternative = "two.sided"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 14.12004 164.39083
}
\keyword{htest}