\name{z.test}
\alias{z.test}

\title{Interface for z-Test}
\description{
 User friendly implementation of \code{\link[PASWR]{z.test}}.
 This function is based on the standard normal distribution and 
 creates confidence intervals and tests hypotheses for both one 
 and two sample problems. 
}
\usage{
# z.test()

z.test(x,
       sigma.x = NULL,
       y=NULL,
       sigma.y = NULL,
       mu = 0,
       alternative = "two.sided",
       conf.level = 0.95,
       interactive = FALSE)
}

\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{numeric vector; \code{NA}s and \code{Inf}s are allowed 
  but will be removed.}
  \item{y}{numeric vector; \code{NA}s and \code{Inf}s are allowed 
  but will be removed.}
  \item{sigma.x}{a single number representing the population standard 
  deviation for \code{x}}
  \item{sigma.y}{a single number representing the population standard 
  deviation for \code{y}}
  \item{mu}{a single number representing the value of the mean or 
  difference in means specified by the null hypothesis}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[PASWR]{z.test}}.
  Will return a list with the following values.
} 

\value{
A list containing the following components: 
  \item{test.statistic}{the z-statistic}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{is a confidence interval for the 
  true mean or difference in means.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[PASWR]{z.test}}.
  
  }
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
\code{\link[PASWR]{z.test}} for the function that implements the
  test.
}

\examples{
## Exercise 12 (Modified) on Page 393 from Essentials of Mathematical Statistics
## A researcher asked 33 mothers who had their first child prior to 1993 thier
## age at the birth of their first child. Test the claim that the average
## age of a mother at the birth of their first child before 1993 is greater
## than 24 at the 95\% confidence level. The population standard deviation is
## 4 years.

## Data
before.1993 <- c(15, 17, 19, 19, 20, 20, 20, 21, 21, 21, 21, 21, 21, 22,
23, 23, 23, 23, 24, 24, 24, 24, 24, 25, 25, 26, 26, 27, 28, 28, 28, 30, 32)

## Parameters
## We want to know if the average age is greater than 24, so alternative = "greater"
## and mu = 24. Sigma.x = 4 years.

## Method
out <- z.test(before.1993, sigma.x=4, mu = 24, alternative = "greater")

## Results
## out$test.statistic = -1.175024
## out$p.value = 0.239985
## out$alternative = "greater"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = 21.81707 24.54656

## Remainder of Exercise 12 (modified)
## After collecting data from the group of mothers who had their first child
## before 1993, the researcher then asked the same question of 33 mothers who
## had their first child in 1993 or later. Assume these data are randomly
## selected, use the 2-sample Z-test to test the claim that the mean age of
## mothers who had their first child prior to 1993 is less than the mean age of
## mothers who had their first child in 1993 or later. The population standard
## deviation for the before.1993 group is 4 years, while the population standard
## devation for the after group is 3 years.

## Data
after <- c(16, 18, 19, 20, 20, 21, 22, 22, 22, 22, 22, 22, 24, 25, 25, 25, 26,
26, 26, 26, 27, 27, 27, 27, 28, 28, 29, 30, 32, 33, 33, 35, 35)

## Parameters
## It is given that x is before.1993 and y is after. It is also given that
## sigma.x = 4 and sigma.y = 3. If the mean age is increasing, than the
## before.1993 group will have a smaller mean. Thus, alternative = "less".

## Method
out <- z.test(x = before.1993, sigma.x = 4, y = after, sigma.y = 3, alternative = "less")

## Results
## out$test.statistic = -2.611165
## out$p.value = 0.009023439
## out$alternative = "less"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = -3.9786570 -0.5667976
}
\keyword{htest}
