\name{zsum.test}
\alias{zsum.test}

\title{Interface for Summarized z-Test}
\description{
 User friendly implementation of \code{\link[PASWR]{zsum.test}}.
 This function is based on the standard normal distribution and 
 creates confidence intervals and tests hypotheses for both one 
 and two sample problems based on summarized information the user 
 passes to the function.
}
\usage{
# zsum.test()

zsum.test(n.x,
          mean.x,
          sigma.x,
          n.y = NULL,
          mean.y = NULL,
          sigma.y = NULL,
          mu = 0,
          alternative = "two.sided",
          conf.level = 0.95,
          interactive = FALSE)
}

\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{n.x}{a single number representing the sample size for \code{x}}
  \item{mean.x}{a single number representing the sample mean of \code{x}}
  \item{sigma.x}{a single number representing the population standard deviation for \code{x}}
  \item{n.y}{a single number representing the sample size for \code{y}}
  \item{mean.y}{a single number representing the sample mean of \code{y}}
  \item{sigma.y}{a single number representing the population standard deviation for \code{y}}
  \item{mu}{a single number representing the value of the mean or difference in means 
  specified by the null hypothesis}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}

\details{
Takes the above input parameters and passes them to \code{\link[PASWR]{zsum.test}}.
  Will return a list with the following values.
}

\value{
A list containing the following components: 
  \item{test.statistic}{the z-statistic}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{is a confidence interval for the 
  true mean or difference in means.}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[PASWR]{zsum.test}}.
}  
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
\code{\link[PASWR]{zsum.test}} for the function that implements the
  test.
}

\examples{
## Example 5.3.1 from Essentials of Mathematical Statistics
## Suppose a random sample of 150 college students has a mean IQ
## of 112.5. We want to test the claim that the mean IQ of college
## students is greater than 110 at the 95\% confidence level.
## Typically, IQ scores have a variance of 15 squared.

## Parameters
## Since this is a 1 sample example, we will not use the
## n.y, mean.y, or sigma.y arguments.
## The number of college students sampled is n.x = 150.
## The mean.x is 112.5, and the population standard deviation
## is the square root of the population variance, so s.x = 15.
## The alternative hypothesis is that IQ is greater than a 
## mean of 110. Thus, alternative = "greater" and mu = 110.

## Method
out <- zsum.test(n.x = 150, mean.x = 112.5, sigma.x = 15, mu = 110, alternative = "greater")

## Results
## out$test.statistic = 2.041241
## out$p.value = 0.026061342
## out$alternative = "greater"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 110.4855 Inf

## Exercise 1 on page 390
## A sample of 47 education majors at a certain university has a mean
## GPA of 3.46 and a standard deviation of 0.336 while a sample of 53
## noneducation majors has a mean GPA of 3.38 and a standard deviation
## of 0.449 (data collected by Nicole Sempek and Allison Chrismer, 2009).
## Use a 2-sample Z-test to test the claim that education majors at this
## university have a higher mean GPA than noneducation majors.

## Parameters
## We are told that n.x = 47, mean.x = 3.46, sigma.x = 0.336,
## n.y = 53, mean.y = 3.38, sigma.y = 0.449. Our alternative hypothesis
## is "greater" with a default confidence level of 0.95.

## Method
out <- zsum.test(n.x = 47, mean.x = 3.46, sigma.x = 0.336,
n.y = 53, mean.y = 3.38, sigma.y = 0.449, alternative = "greater")

## Results
## out$test.statistic = 1.015523
## out$p.value = 0.1549282
## out$alternative = "greater"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## out$conf.int = -0.04957684 Inf
}
\keyword{htest}
